@@ -2,7 +2,7 @@ use crate::markdown::line::{Line, LineType};
 use self::decoration::render_code_spans;
 
 mod decoration;
-mod link;
+pub mod link;
 pub mod tag;
 
 
@@ -47,10 +47,15 @@ pub fn render_inline(mut line: Line) -> Line {
 
         LineType::Paragraph | LineType::Header | LineType::Blockquote(_)
         | LineType::OrderedList | LineType::UnorderedList => {
-            let new_content = render_code_spans(&line.content);
+            let new_content = render_inline_raw(&line.content);
             line.content = new_content;
 
             line
         }
     }
+}
+
+
+pub fn render_inline_raw(content: &Vec<u16>) -> Vec<u16> {
+    render_code_spans(content)
 }
\ No newline at end of file
