@@ -81,7 +81,7 @@ pub fn translate_to_latex(content: &Vec<u16>) -> Vec<u16> {
                         result.push(into_v16("\\{ "));
                     }
 
-                    else if tmp == into_v16("leftcurlybrace") {
+                    else if tmp == into_v16("rightcurlybrace") {
                         result.push(into_v16("\\} "));}
 
                     else {
@@ -100,29 +100,42 @@ pub fn translate_to_latex(content: &Vec<u16>) -> Vec<u16> {
 
                     if arguments.len() > 0 {
 
-                        let func_name = if tmp == into_v16("sup") {
-                            vec![U16_CARET]
-                        }
+                        if tmp == into_v16("lim") {
+                            let argument = translate_to_latex(&arguments[0]);
 
-                        else if tmp == into_v16("sub") {
-                            vec![U16_UNDERBAR]
+                            result.push(vec![
+                                into_v16("\\lim\\limits_{"),
+                                argument,
+                                vec![U16_RIGHT_CURLY_BRACE],
+                            ].concat());
                         }
 
                         else {
-                            vec![
-                                vec![U16_BACKSLASH],
-                                tmp
-                            ].concat()
-                        };
+                            let func_name = if tmp == into_v16("sup") {
+                                vec![U16_CARET]
+                            }
 
-                        let argument = translate_to_latex(&arguments[0]);
+                            else if tmp == into_v16("sub") {
+                                vec![U16_UNDERBAR]
+                            }
 
-                        result.push(vec![
-                            func_name,
-                            vec![U16_LEFT_CURLY_BRACE],
-                            argument,
-                            vec![U16_RIGHT_CURLY_BRACE],
-                        ].concat());
+                            else {
+                                vec![
+                                    vec![U16_BACKSLASH],
+                                    tmp
+                                ].concat()
+                            };
+
+                            let argument = translate_to_latex(&arguments[0]);
+
+                            result.push(vec![
+                                func_name,
+                                vec![U16_LEFT_CURLY_BRACE],
+                                argument,
+                                vec![U16_RIGHT_CURLY_BRACE],
+                            ].concat());
+
+                        }
 
                         tmp = vec![];
                         index = indexes[0] + 1;
@@ -204,7 +217,7 @@ pub fn translate_to_latex(content: &Vec<u16>) -> Vec<u16> {
                             result.push(vec![
                                 vec![U16_BACKSLASH],
                                 tmp,
-                                vec![U16_UNDERBAR, U16_LEFT_CURLY_BRACE],
+                                into_v16("\\limits _{"),
                                 argument1,
                                 vec![U16_RIGHT_CURLY_BRACE, U16_CARET, U16_LEFT_CURLY_BRACE],
                                 argument2,
@@ -335,7 +348,7 @@ fn is_closing_math_tag(content: &[u16], index: usize) -> bool {
 
 
 const LATEX_SYMBOLS_RAW: [&str;98] = ["lt", "gt", "leq", "geq", "ll", "gg", "equiv", "subset", "supset", "approx", "in", "ni", "subseteq", "supseteq", "cong", "simeq", "notin", "propto", "neq", "therefore", "because", "pm", "mp", "times", "div", "star", "cap", "cup", "vee", "wedge", "cdot", "diamond", "bullet", "oplus", "ominus", "otimes", "oslash", "odot", "circ", "exists", "nexists", "forall", "neg", "land", "lor", "rightarrow", "leftarrow", "iff", "top", "bot", "varnothing", "quad", "backslash", "leftcurlybrace", "rightcurlybrace", "alpha", "beta", "gamma", "Gamma", "delta", "Delta", "epsilon", "zeta", "eta", "theta", "Theta", "iota", "kappa", "lambda", "Lambda", "mu", "nu", "xi", "Xi", "pi", "Pi", "rho", "sigma", "Sigma", "tau", "upsilon", "Upsilon", "phi", "Phi", "chi", "psi", "Psi", "omega", "Omega", "partial", "nabla", "infty", "cos", "sin", "tan", "cosh", "sinh", "tanh"];
-const LATEX_1ARG_FUNCS_RAW: [&str;12] = ["sub", "sup", "hat", "bar", "dot", "tilde", "vec", "check", "overleftarrow", "overrightarrow", "underline", "text"];
+const LATEX_1ARG_FUNCS_RAW: [&str;13] = ["sub", "sup", "hat", "bar", "dot", "tilde", "vec", "check", "overleftarrow", "overrightarrow", "underline", "text", "lim"];
 const LATEX_2ARG_FUNCS_RAW: [&str;9] = ["frac", "cfrac", "sqrt", "int", "oint", "iint", "iiint", "sum", "prod"];
 
 
@@ -371,7 +384,7 @@ mod tests {
         let orig = crate::utils::into_v16("int{0}{infty} e sup{-x} dx");
         let rendered = String::from_utf16_lossy(&crate::markdown::math::translate_to_latex(&orig));
 
-        assert_eq!(rendered, "\\int_{0}^{\\infty } e ^{-x} dx".to_string());
+        assert_eq!(rendered, "\\int\\limits _{0}^{\\infty } e ^{-x} dx".to_string());
     }
 
     #[test]
@@ -387,7 +400,7 @@ mod tests {
         let orig = crate::utils::into_v16("sum{n=1}{infty} frac{1}{n sup{2}} < 10");
         let rendered = String::from_utf16_lossy(&crate::markdown::math::translate_to_latex(&orig));
 
-        assert_eq!(rendered, "\\sum_{n=1}^{\\infty } \\frac{1}{n ^{2}}  \\lt   10".to_string());
+        assert_eq!(rendered, "\\sum\\limits _{n=1}^{\\infty } \\frac{1}{n ^{2}}  \\lt   10".to_string());
     }
 
 }
\ No newline at end of file
